@@ -1,6 +1,7 @@
 package Image::TextMode::Writer::ANSIMation;
 
 use Moose;
+use charnames ':full';
 
 extends 'Image::TextMode::Writer';
 
@@ -8,7 +9,7 @@ sub _write {
     my ( $self, $anim, $fh, $options ) = @_;
 
     # clear screen
-    print $fh "\x1b[2J";
+    print $fh "\N{ESCAPE}[2J";
 
     my $prevattr = '';
     for my $image ( @{ $anim->frames } ) {
@@ -26,7 +27,7 @@ sub _write {
                 my $pixel = $image->getpixel( $x, $y ) || { char => ' ', attr => 7 };
                 my $attr = _gen_args( $pixel->{ attr } );
                 if( $attr ne $prevattr ) {
-                    print $fh "\x1b[0;", _gen_args( $pixel->{ attr } ), 'm';
+                    print $fh "\N{ESCAPE}[0;", _gen_args( $pixel->{ attr } ), 'm';
                     $prevattr = $attr;
                 }
                 print $fh $pixel->{ char }; 
@@ -36,12 +37,12 @@ sub _write {
 
         # set position
         if( $image ne $anim->frames->[ -1 ] ) {
-            print $fh "\x1b[H";
+            print $fh "\N{ESCAPE}[H";
         }
     }
 
     # clear attrs
-    print $fh "\x1b[0m";
+    print $fh "\N{ESCAPE}[0m";
 }
 
 sub _gen_args {
@@ -50,7 +51,7 @@ sub _gen_args {
     my $bg = 40 + ( ( $attr & 112 ) >> 4 );
     my $bl = ( $attr & 128 ) ? 5 : '';
     my $in = ( $attr & 8 ) ? 1 : '';
-    return join ( ';', grep { length } ( $bl, $in, $fg, $bg ) ); 
+    return join ( q{;}, grep { length } ( $bl, $in, $fg, $bg ) ); 
 }
 
 no Moose;
@@ -61,6 +62,10 @@ __PACKAGE__->meta->make_immutable;
 
 Image::TextMode::Writer::ANSIMation - Writes ANSIMation files
 
+=head1 DESCRIPTION
+
+Provides writing capabilities for the ANSIMation format.
+
 =head1 AUTHOR
 
 Brian Cassidy E<lt>bricas@cpan.orgE<gt>
